# Service health API Logging Integration

These protos represent the Service health API log entry schema. The Service Health API log schema represents updates to a service health event's information as a distinct log in Cloud Logging. This information includes description, relevance, state, impacted products, and impacted locations.
